==> haskell-infer-license-0.2.0-308-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-infer-license.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 infer-license
version:              0.2.0
visibility:           public
id:                   infer-license-0.2.0-8R3vx29NcW9IoRqcX2ajYr
key:                  infer-license-0.2.0-8R3vx29NcW9IoRqcX2ajYr
license:              MIT
copyright:            (c) 2018 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
synopsis:             Infer software license from a given license file
category:             Development
abi:                  8c3f7bc140e25863234777ab6556b185
exposed:              True
exposed-modules:      Data.License.Infer
hidden-modules:
    Data.License.SpdxLicenses Data.License.Type Paths_infer_license

import-dirs:          /usr/lib/ghc-9.4.8/site-local/infer-license-0.2.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/infer-license-0.2.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/infer-license-0.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-infer-license
hs-libraries:         HSinfer-license-0.2.0-8R3vx29NcW9IoRqcX2ajYr
depends:
    base-4.17.2.1 directory-1.3.7.1 filepath-1.4.2.2 text-2.0.2
    text-metrics-0.3.2-2Modhn7Nzj2LI8ukWKxtEC

haddock-interfaces:
    /usr/share/doc/haskell-infer-license/html/infer-license.haddock

haddock-html:         /usr/share/doc/haskell-infer-license/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-infer-license-0.2.0-309-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-infer-license.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 infer-license
version:              0.2.0
visibility:           public
id:                   infer-license-0.2.0-4v8X7L9LS5WJgo5Vilfmxl
key:                  infer-license-0.2.0-4v8X7L9LS5WJgo5Vilfmxl
license:              MIT
copyright:            (c) 2018 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
synopsis:             Infer software license from a given license file
category:             Development
abi:                  487ea8008ada3f161ec4f18017634462
exposed:              True
exposed-modules:      Data.License.Infer
hidden-modules:
    Data.License.SpdxLicenses Data.License.Type Paths_infer_license

import-dirs:          /usr/lib/ghc-9.4.8/site-local/infer-license-0.2.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/infer-license-0.2.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/infer-license-0.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-infer-license
hs-libraries:         HSinfer-license-0.2.0-4v8X7L9LS5WJgo5Vilfmxl
depends:
    base-4.17.2.1 directory-1.3.7.1 filepath-1.4.2.2 text-2.0.2
    text-metrics-0.3.2-EL24sQwdispG5l93P15vb5

haddock-interfaces:
    /usr/share/doc/haskell-infer-license/html/infer-license.haddock

haddock-html:         /usr/share/doc/haskell-infer-license/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
